# apxs script location
%{!?_httpd_apxs: %global _httpd_apxs %{_sbindir}/apxs}

# Module Magic Number
%{!?_httpd_mmn: %global _httpd_mmn %(cat %{_includedir}/httpd/.mmn 2>/dev/null || echo 0-0)}

# Configuration directory
%{!?_httpd_confdir: %global _httpd_confdir %{_sysconfdir}/httpd/conf.d}

# For httpd 2.4 and above we have a different filesystem layout
%if 0%{?fedora} > 17 || 0%{?rhel} > 6
%global httpd24 1
%else
%global httpd24 0
%endif

Summary:	Apache2 module for high-performance server-side scripting
Name:		mod_fastcgi
Version:	2.4.7.1
Release:	1%{?dist}
License:	Open Market FastCGI
URL:		https://github.com/FastCGI-Archives/mod_fastcgi
Source0:	https://github.com/FastCGI-Archives/mod_fastcgi/archive/%{version}.tar.gz
Source1:	fastcgi.conf
Source2:	fastcgi24.conf
Patch3:		https://github.com/ByteInternet/libapache-mod-fastcgi/raw/byte/debian/patches/doc-misc-typo-fix.diff
Patch4:		fastcgi-FD_SETSIZE-bug.patch
Requires:	httpd >= 2.0
Requires:	httpd-mmn = %{_httpd_mmn}
BuildRequires:	gcc, httpd-devel >= 2.0, make, pkgconfig

%description
This third-party module provides support for the FastCGI protocol. FastCGI is a
language-independent, scalable, open extension to CGI that provides high
performance and persistence without the limitations of server specific APIs.

Note that the license terms for this package include a field-of-use restriction
and that it is therefore not free software - see LICENSE.TERMS.

%prep
%setup -q -n mod_fastcgi-%{version}

# Fix documentation typo
%patch3 -p1

# Remove useless FD_SETSIZE check
# (http://bugs.debian.org/cgi-bin/bugreport.cgi?bug=656425)
%patch4 -p1

cp Makefile.AP2 Makefile

%build
topdir=$(dirname $(%{_httpd_apxs} -q exp_installbuilddir))
make top_dir=${topdir}

%install
topdir=$(dirname $(%{_httpd_apxs} -q exp_installbuilddir))
make \
	top_dir=${topdir} \
	DESTDIR=%{buildroot} \
	MKINSTALLDIRS="mkdir -p" \
	install

# Install the config file
%if %{httpd24}
mkdir -p %{buildroot}%{_httpd_modconfdir}
echo "LoadModule fastcgi_module modules/mod_fastcgi.so" > %{buildroot}%{_httpd_modconfdir}/10-fastcgi.conf
install -p -m 644 -D %{SOURCE2} %{buildroot}%{_httpd_confdir}/fastcgi.conf
%else
install -p -m 644 -D %{SOURCE1} %{buildroot}%{_httpd_confdir}/fastcgi.conf
%endif

%files
%doc CHANGES docs/
%{_libdir}/httpd/modules/mod_fastcgi.so
%if %{httpd24}
%config(noreplace) %{_httpd_modconfdir}/10-fastcgi.conf
%endif
%config(noreplace) %{_httpd_confdir}/fastcgi.conf

%changelog
* Mon Oct 15 2018 Paul Howarth <paul@city-fan.org> - 2.4.7.1-1
- Switch upstream to FastCGI-Archives on GitHub
  - *nix: On graceful restart, send SIGTERM, then wait 2 seconds before 
    removing any unix domain sockets
  - Fix uid_t/gid_t compiler warnings
  - A few more EINTR fixes
  - Don't let the Content-Length header propagate on errors or across redirects
  - Fix pass-header handling (prefix with HTTP_)
  - Add an EOS bucket to the output filter chain
  - Handle EINTR and EAGAIN in places AIX stress testing revealed issues
  - Fix process spawning on WIN under Apache 2.2.9 (an incompatible change was
    introduced in APR 1.3)
  - Allow duplicate Status, Location and Content-Type headers (consistent with
    mod_cgi)
  - Fix a spurious idle timeout error that occurred under unique application
    timing and response size conditions
  - Fix cast from pointer to integer of different size
  - Fix printf %%d warning
  - Apache 2.4 compile fix

* Wed Aug  9 2017 Paul Howarth <paul@city-fan.org> - 2.4.6-6
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section

* Fri Feb  5 2016 Paul Howarth <paul@city-fan.org> - 2.4.6-5
- Fix Module Magic Number definition
- Drop %%defattr, redundant since rpm 4.4

* Wed May  2 2012 Paul Howarth <paul@city-fan.org> - 2.4.6-4
- Use 10- prefix for conf file in conf.modules.d with httpd ≥ 2.4
- Use %%{_httpd_confdir} unconditionally

* Mon Apr 23 2012 Paul Howarth <paul@city-fan.org> - 2.4.6-3
- Use upstream snapshot tarball from test.fastcgi.com and drop patch with the
  changes from that snapshot
- Remove useless FD_SETSIZE check
  (http://bugs.debian.org/cgi-bin/bugreport.cgi?bug=656425)
- Add another patch from Byte Internet to fix a documentation typo

* Tue Mar 27 2012 Paul Howarth <paul@city-fan.org> - 2.4.6-2
- Include fixes from upstream snapshot dated 2009-10-05
- Fix compatibility with httpd 2.4 in F-18/RHEL-7 onwards
  (patches from Byte Internet on GitHub)
- Nobody else likes macros for commands

* Wed Jun 24 2009 Paul Howarth <paul@city-fan.org> - 2.4.6-1
- Update to 2.4.6
- Drop all existing patches - applied upstream
- Add note about field-of-use restriction in %%description
- Add buildreq of pkgconfig, a missing dependency of both apr-devel and
  apr-util-devel on FC5

* Wed May 30 2007 Paul Howarth <paul@city-fan.org> - 2.4.2-4
- incorporate changes from latest upstream snapshot (dated 2004!) sent by
  Torsten Kalix <tkalix@bredex.de>, mainly related to restart backoff handling
- include mod_fastcgi-2.4.2-fix_warnings.patch, also from Torsten Kalix

* Mon Jul 24 2006 Paul Howarth <paul@city-fan.org> - 2.4.2-3
- Fix FC6 build (/etc/httpd/build symlink gone)

* Wed Mar 22 2006 Paul Howarth <paul@city-fan.org> - 2.4.2-2
- Add patch to support Apache httpd 2.2
  (http://fastcgi.com/archives/fastcgi-developers/2005-December/004060.html)

* Mon Jan 16 2006 Paul Howarth <paul@city-fan.org> - 2.4.2-1
- Initial RPM build
